@@ -27,7 +27,6 @@
 #include <stdlib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
 #include <packagekit-glib2/packagekit.h>
 
@@ -47,7 +46,6 @@
 #include "gs-shell-search-provider.h"
 #include "gs-offline-updates.h"
 #include "gs-folders.h"
-#include "gs-utils.h"
 
 
 struct _GsApplication {
@@ -98,8 +96,7 @@ download_updates_setting_changed (GSettings     *settings,
 				  const gchar   *key,
 				  GsApplication *app)
 {
-	if (!gs_updates_are_managed () &&
-	    g_settings_get_boolean (settings, key)) {
+	if (g_settings_get_boolean (settings, key)) {
 		g_debug ("Enabling update monitor");
 		app->update_monitor = gs_update_monitor_new (app);
 	} else {
@@ -108,27 +105,6 @@ download_updates_setting_changed (GSettings     *settings,
 	}
 }
 
-static void
-on_permission_changed (GPermission *permission,
-                       GParamSpec  *pspec,
-                       gpointer     data)
-{
-	GsApplication *app = data;
-
-	if (app->settings)
-		download_updates_setting_changed (app->settings, "download-updates", app);
-}
-
-static void
-gs_application_monitor_permission (GsApplication *app)
-{
-	GPermission *permission;
-
-	permission = gs_offline_updates_permission_get ();
-	g_signal_connect (permission, "notify",
-			  G_CALLBACK (on_permission_changed), app);
-}
-
 static void
 gs_application_monitor_updates (GsApplication *app)
 {
@@ -258,20 +234,6 @@ gs_application_initialize_ui (GsApplication *app)
 				  G_CALLBACK (gtk_window_present), gs_shell_get_window (app->shell));
 }
 
-static void
-initialize_ui_and_present_window (GsApplication *app)
-{
-	GList *windows;
-	GtkWindow *window;
-
-	gs_application_initialize_ui (app);
-	windows = gtk_application_get_windows (GTK_APPLICATION (app));
-	if (windows) {
-		window = windows->data;
-		gtk_window_present (window);
-	}
-}
-
 static void
 sources_activated (GSimpleAction *action,
 		   GVariant      *parameter,
@@ -364,8 +326,15 @@ set_mode_activated (GSimpleAction *action,
 {
 	GsApplication *app = GS_APPLICATION (data);
 	const gchar *mode;
+	GList *windows;
+	GtkWindow *window = NULL;
 
-	initialize_ui_and_present_window (app);
+	gs_application_initialize_ui (app);
+	windows = gtk_application_get_windows (GTK_APPLICATION (app));
+	if (windows) {
+		window = windows->data;
+		gtk_window_present (window);
+	}
 
 	mode = g_variant_get_string (parameter, NULL);
 	if (g_strcmp0 (mode, "updates") == 0) {
@@ -389,8 +358,15 @@ search_activated (GSimpleAction *action,
 {
 	GsApplication *app = GS_APPLICATION (data);
 	const gchar *search;
+	GList *windows;
+	GtkWindow *window = NULL;
 
-	initialize_ui_and_present_window (app);
+	gs_application_initialize_ui (app);
+	windows = gtk_application_get_windows (GTK_APPLICATION (app));
+	if (windows) {
+		window = windows->data;
+		gtk_window_present (window);
+	}
 
 	search = g_variant_get_string (parameter, NULL);
 	gs_shell_show_search (app->shell, search);
@@ -402,10 +378,17 @@ details_activated (GSimpleAction *action,
 		   gpointer       data)
 {
 	GsApplication *app = GS_APPLICATION (data);
+	GList *windows;
+	GtkWindow *window = NULL;
 	const gchar *id;
 	const gchar *search;
 
-	initialize_ui_and_present_window (app);
+	windows = gtk_application_get_windows (GTK_APPLICATION (app));
+	if (windows) {
+		window = windows->data;
+		gtk_window_present (window);
+	}
+	gs_application_initialize_ui (app);
 
 	g_variant_get (parameter, "(&s&s)", &id, &search);
 	if (search != NULL && search[0] != '\0')
@@ -458,12 +441,7 @@ show_offline_updates_error (GSimpleAction *action,
 			    GVariant      *parameter,
 			    gpointer       data)
 {
-	GsApplication *app = GS_APPLICATION (data);
-
-	initialize_ui_and_present_window (app);
-
-	gs_shell_set_mode (app->shell, GS_SHELL_MODE_UPDATES);
-	gs_offline_updates_show_error (app->shell);
+	gs_offline_updates_show_error ();
 }
 
 static void
@@ -475,6 +453,8 @@ install_resources_activated (GSimpleAction *action,
 #ifdef GDK_WINDOWING_X11
 	GdkDisplay *display;
 #endif
+	GList *windows;
+	GtkWindow *window = NULL;
 	const gchar *mode;
 	const gchar *startup_id;
 	gchar **resources;
@@ -491,7 +471,12 @@ install_resources_activated (GSimpleAction *action,
 	}
 #endif
 
-	initialize_ui_and_present_window (app);
+	windows = gtk_application_get_windows (GTK_APPLICATION (app));
+	if (windows) {
+		window = windows->data;
+		gtk_window_present (window);
+	}
+	gs_application_initialize_ui (app);
 
 	gs_shell_show_extras_search (app->shell, mode, resources);
 }
@@ -525,7 +510,6 @@ gs_application_startup (GApplication *application)
 	GS_APPLICATION (application)->proxy_settings = gs_proxy_settings_new ();
 	GS_APPLICATION (application)->dbus_helper = gs_dbus_helper_new ();
 	GS_APPLICATION (application)->settings = g_settings_new ("org.gnome.software");
-	gs_application_monitor_permission (GS_APPLICATION (application));
 	gs_application_monitor_updates (GS_APPLICATION (application));
 	gs_application_provide_search (GS_APPLICATION (application));
 	gs_application_monitor_network (GS_APPLICATION (application));
