@@ -54,6 +54,16 @@ gs_category_get_size (GsCategory *category)
 	return category->priv->size;
 }
 
+/**
+ * gs_category_set_size:
+ **/
+void
+gs_category_set_size (GsCategory *category, guint size)
+{
+	g_return_if_fail (GS_IS_CATEGORY (category));
+	category->priv->size = size;
+}
+
 /**
  * gs_category_increment_size:
  *
