@@ -148,6 +148,10 @@ typedef gboolean	 (*GsPluginFilenameToAppFunc)	(GsPlugin	*plugin,
 							 const gchar	*filename,
 							 GCancellable	*cancellable,
 							 GError		**error);
+typedef gboolean	 (*GsPluginOfflineUpdateFunc)	(GsPlugin	*plugin,
+							 GList		*apps,
+							 GCancellable	*cancellable,
+							 GError		**error);
 
 const gchar	*gs_plugin_get_name			(void);
 void		 gs_plugin_initialize			(GsPlugin	*plugin);
@@ -229,10 +233,6 @@ gboolean	 gs_plugin_app_install			(GsPlugin	*plugin,
 							 GsApp		*app,
 							 GCancellable	*cancellable,
 							 GError		**error);
-gboolean	 gs_plugin_app_update			(GsPlugin	*plugin,
-							 GsApp		*app,
-							 GCancellable	*cancellable,
-							 GError		**error);
 gboolean	 gs_plugin_app_remove			(GsPlugin	*plugin,
 							 GsApp		*app,
 							 GCancellable	*cancellable,
@@ -241,10 +241,6 @@ gboolean	 gs_plugin_app_set_rating		(GsPlugin	*plugin,
 							 GsApp		*app,
 							 GCancellable	*cancellable,
 							 GError		**error);
-gboolean	 gs_plugin_app_upgrade			(GsPlugin	*plugin,
-							 GsApp		*app,
-							 GCancellable	*cancellable,
-							 GError		**error);
 gboolean	 gs_plugin_refresh			(GsPlugin	*plugin,
 							 guint		 cache_age,
 							 GsPluginRefreshFlags flags,
@@ -255,6 +251,10 @@ gboolean	 gs_plugin_filename_to_app		(GsPlugin	*plugin,
 							 const gchar	*filename,
 							 GCancellable	*cancellable,
 							 GError		**error);
+gboolean	 gs_plugin_offline_update		(GsPlugin	*plugin,
+							 GList		*apps,
+							 GCancellable	*cancellable,
+							 GError		**error);
 
 G_END_DECLS
 
