@@ -230,15 +230,16 @@ gs_screenshot_image_complete_cb (SoupSession *session,
 				 SoupMessage *msg,
 				 gpointer user_data)
 {
-	GsScreenshotImagePrivate *priv;
+	_cleanup_object_unref_ GsScreenshotImage *ssimg = GS_SCREENSHOT_IMAGE (user_data);
+	GsScreenshotImagePrivate *priv = gs_screenshot_image_get_instance_private (ssimg);
 	gboolean ret;
 	_cleanup_error_free_ GError *error = NULL;
 	_cleanup_object_unref_ AsImage *im = NULL;
 	_cleanup_object_unref_ GdkPixbuf *pixbuf = NULL;
 	_cleanup_object_unref_ GInputStream *stream = NULL;
-	_cleanup_object_unref_ GsScreenshotImage *ssimg = GS_SCREENSHOT_IMAGE (user_data);
 
-	if (msg->status_code == SOUP_STATUS_CANCELLED)
+	/* return immediately if the message was cancelled or if we're in destruction */
+	if (msg->status_code == SOUP_STATUS_CANCELLED || priv->session == NULL)
 		return;
 
 	if (msg->status_code != SOUP_STATUS_OK) {
@@ -249,8 +250,6 @@ gs_screenshot_image_complete_cb (SoupSession *session,
 		return;
 	}
 
-	priv = gs_screenshot_image_get_instance_private (ssimg);
-
 	/* create a buffer with the data */
 	stream = g_memory_input_stream_new_from_data (msg->response_body->data,
 						      msg->response_body->length,
@@ -498,12 +497,11 @@ gs_screenshot_image_destroy (GtkWidget *widget)
 		g_clear_object (&priv->message);
 	}
 	g_clear_object (&priv->screenshot);
-	g_free (priv->cachedir);
-	priv->cachedir = NULL;
-	g_free (priv->filename);
-	priv->filename = NULL;
 	g_clear_object (&priv->session);
 
+	g_clear_pointer (&priv->cachedir, g_free);
+	g_clear_pointer (&priv->filename, g_free);
+
 	GTK_WIDGET_CLASS (gs_screenshot_image_parent_class)->destroy (widget);
 }
 
