@@ -32,7 +32,6 @@
 
 struct GsPluginPrivate {
 	AsStore			*store;
-	GMutex			 store_mutex;
 	gchar			*locale;
 	gsize			 done_init;
 	gboolean		 has_hi_dpi_support;
@@ -89,7 +88,6 @@ void
 gs_plugin_initialize (GsPlugin *plugin)
 {
 	plugin->priv = GS_PLUGIN_GET_PRIVATE (GsPluginPrivate);
-	g_mutex_init (&plugin->priv->store_mutex);
 	plugin->priv->store = as_store_new ();
 	g_signal_connect (plugin->priv->store, "changed",
 			  G_CALLBACK (gs_plugin_appstream_store_changed_cb),
@@ -109,7 +107,7 @@ const gchar **
 gs_plugin_get_deps (GsPlugin *plugin)
 {
 	static const gchar *deps[] = {
-		"hardcoded-categories",	/* need category list */
+		"menu-spec-categories",	/* need category list */
 		NULL };
 	return deps;
 }
@@ -122,7 +120,6 @@ gs_plugin_destroy (GsPlugin *plugin)
 {
 	g_free (plugin->priv->locale);
 	g_object_unref (plugin->priv->store);
-	g_mutex_clear (&plugin->priv->store_mutex);
 }
 
 /**
@@ -187,8 +184,6 @@ gs_plugin_startup (GsPlugin *plugin, GError **error)
 	guint i;
 	_cleanup_hashtable_unref_ GHashTable *origins = NULL;
 
-	g_mutex_lock (&plugin->priv->store_mutex);
-
 	/* clear all existing applications if the store was invalidated */
 	as_store_remove_all (plugin->priv->store);
 
@@ -249,7 +244,6 @@ gs_plugin_startup (GsPlugin *plugin, GError **error)
 		}
 	}
 out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
 	gs_profile_stop (plugin->profile, "appstream::startup");
 	return ret;
 }
@@ -672,8 +666,6 @@ gs_plugin_refine_from_id (GsPlugin *plugin,
 	gboolean ret = TRUE;
 	AsApp *item = NULL;
 
-	g_mutex_lock (&plugin->priv->store_mutex);
-
 	/* find anything that matches the ID */
 	id = gs_app_get_id (app);
 	if (id == NULL)
@@ -687,7 +679,6 @@ gs_plugin_refine_from_id (GsPlugin *plugin,
 	if (!ret)
 		goto out;
 out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
 	*found = (item != NULL);
 	return ret;
 }
@@ -702,12 +693,9 @@ gs_plugin_refine_from_pkgname (GsPlugin *plugin,
 {
 	AsApp *item = NULL;
 	GPtrArray *sources;
-	gboolean ret = TRUE;
 	const gchar *pkgname;
 	guint i;
 
-	g_mutex_lock (&plugin->priv->store_mutex);
-
 	/* find anything that matches the ID */
 	sources = gs_app_get_sources (app);
 	for (i = 0; i < sources->len && item == NULL; i++) {
@@ -720,13 +708,10 @@ gs_plugin_refine_from_pkgname (GsPlugin *plugin,
 
 	/* nothing found */
 	if (item == NULL)
-		goto out;
+		return TRUE;
 
 	/* set new properties */
-	ret = gs_plugin_refine_item (plugin, app, item, error);
-out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
-	return ret;
+	return gs_plugin_refine_item (plugin, app, item, error);
 }
 
 /**
@@ -749,7 +734,7 @@ gs_plugin_refine (GsPlugin *plugin,
 		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
-			return FALSE;
+			goto out;
 	}
 
 	gs_profile_start (plugin->profile, "appstream::refine");
@@ -795,12 +780,11 @@ gs_plugin_add_category_apps (GsPlugin *plugin,
 		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
-			return FALSE;
+			goto out;
 	}
 
 	/* get the two search terms */
 	gs_profile_start (plugin->profile, "appstream::add-category-apps");
-	g_mutex_lock (&plugin->priv->store_mutex);
 	search_id1 = gs_category_get_id (category);
 	parent = gs_category_get_parent (category);
 	if (parent != NULL)
@@ -832,7 +816,6 @@ gs_plugin_add_category_apps (GsPlugin *plugin,
 		gs_plugin_add_app (list, app);
 	}
 out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
 	gs_profile_stop (plugin->profile, "appstream::add-category-apps");
 	return ret;
 }
@@ -931,12 +914,11 @@ gs_plugin_add_search (GsPlugin *plugin,
 		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
-			return FALSE;
+			goto out;
 	}
 
 	/* search categories for the search term */
 	gs_profile_start (plugin->profile, "appstream::search");
-	g_mutex_lock (&plugin->priv->store_mutex);
 	array = as_store_get_apps (plugin->priv->store);
 	for (i = 0; i < array->len; i++) {
 		if (g_cancellable_set_error_if_cancelled (cancellable, error))
@@ -948,7 +930,6 @@ gs_plugin_add_search (GsPlugin *plugin,
 			goto out;
 	}
 out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
 	gs_profile_stop (plugin->profile, "appstream::search");
 	return ret;
 }
@@ -972,12 +953,11 @@ gs_plugin_add_installed (GsPlugin *plugin,
 		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
-			return FALSE;
+			goto out;
 	}
 
 	/* search categories for the search term */
 	gs_profile_start (plugin->profile, "appstream::add_installed");
-	g_mutex_lock (&plugin->priv->store_mutex);
 	array = as_store_get_apps (plugin->priv->store);
 	for (i = 0; i < array->len; i++) {
 		item = g_ptr_array_index (array, i);
@@ -991,7 +971,6 @@ gs_plugin_add_installed (GsPlugin *plugin,
 		}
 	}
 out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
 	gs_profile_stop (plugin->profile, "appstream::add_installed");
 	return ret;
 }
@@ -1060,12 +1039,11 @@ gs_plugin_add_categories (GsPlugin *plugin,
 		ret = gs_plugin_startup (plugin, error);
 		g_once_init_leave (&plugin->priv->done_init, TRUE);
 		if (!ret)
-			return FALSE;
+			goto out;
 	}
 
 	/* find out how many packages are in each category */
 	gs_profile_start (plugin->profile, "appstream::add-categories");
-	g_mutex_lock (&plugin->priv->store_mutex);
 	array = as_store_get_apps (plugin->priv->store);
 	for (i = 0; i < array->len; i++) {
 		app = g_ptr_array_index (array, i);
@@ -1075,303 +1053,7 @@ gs_plugin_add_categories (GsPlugin *plugin,
 			continue;
 		gs_plugin_add_categories_for_app (*list, app);
 	}
-	g_mutex_unlock (&plugin->priv->store_mutex);
+out:
 	gs_profile_stop (plugin->profile, "appstream::add-categories");
 	return ret;
 }
-
-/**
- * gs_plugin_appstream_is_app_awesome:
- */
-static gboolean
-gs_plugin_appstream_is_app_awesome (GsApp *app)
-{
-	if ((gs_app_get_kudos (app) & GS_APP_KUDO_PERFECT_SCREENSHOTS) == 0)
-		return FALSE;
-	if (gs_app_get_kudos_weight (app) < 4)
-		return FALSE;
-	return TRUE;
-}
-
-/**
- * gs_plugin_add_popular_from_category:
- */
-static gboolean
-gs_plugin_add_popular_from_category (GsPlugin *plugin,
-				     GList **list,
-				     const gchar *category,
-				     const gchar *category_exclude,
-				     GHashTable *ignore_apps,
-				     GError **error)
-{
-	AsApp *item;
-	GError *error_local = NULL;
-	GPtrArray *array;
-	guint i;
-
-	/* search categories for the search term */
-	array = as_store_get_apps (plugin->priv->store);
-	for (i = 0; i < array->len; i++) {
-		_cleanup_object_unref_ GsApp *app = NULL;
-		item = g_ptr_array_index (array, i);
-
-		/* find not-installed desktop application with long descriptions
-		 * and perfect screenshots and that we've not suggested before */
-		if (as_app_get_state (item) == AS_APP_STATE_INSTALLED)
-			continue;
-		if (as_app_get_id_kind (item) != AS_ID_KIND_DESKTOP)
-			continue;
-		if (as_app_get_description (item, NULL) == NULL)
-			continue;
-		if (g_hash_table_lookup (ignore_apps, as_app_get_id (item)) != NULL)
-			continue;
-		if (!as_app_has_category (item, category))
-			continue;
-		if (category_exclude != NULL && as_app_has_category (item, category_exclude))
-			continue;
-		if (plugin->priv->has_hi_dpi_support &&
-		    !as_app_has_kudo_kind (item, AS_KUDO_KIND_HI_DPI_ICON))
-			continue;
-
-		/* add application */
-		app = gs_app_new (as_app_get_id (item));
-		if (!gs_plugin_refine_item (plugin, app, item, &error_local)) {
-			g_warning ("Failed to refine %s: %s",
-				   as_app_get_id (item),
-				   error_local->message);
-			g_clear_error (&error_local);
-			continue;
-		}
-
-		/* only suggest awesome applications */
-		if (gs_plugin_appstream_is_app_awesome (app)) {
-			g_debug ("suggesting %s as others installed from category %s",
-				 as_app_get_id (item), category);
-			gs_plugin_add_app (list, app);
-			g_hash_table_insert (ignore_apps,
-					     (gpointer) as_app_get_id (item),
-					     GINT_TO_POINTER (1));
-		}
-	}
-	return TRUE;
-}
-
-/**
- * gs_plugin_add_popular_by_cat:
- */
-static gboolean
-gs_plugin_add_popular_by_cat (GsPlugin *plugin,
-			      GList **list,
-			      const gchar *category_exclude,
-			      GHashTable *ignore_apps,
-			      GCancellable *cancellable,
-			      GError **error)
-{
-	AsApp *item;
-	GPtrArray *array;
-	GPtrArray *categories;
-	const gchar *tmp;
-	gboolean ret = TRUE;
-	guint i;
-	guint j;
-	_cleanup_hashtable_unref_ GHashTable *ignore_cats = NULL;
-
-	/* ignore main categories */
-	gs_profile_start (plugin->profile, "appstream::add_popular[cat]");
-	ignore_cats = g_hash_table_new (g_str_hash, g_str_equal);
-	g_hash_table_insert (ignore_cats, (gpointer) "Audio", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "Development", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "Education", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "Game", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "Graphics", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "Network", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "Office", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "Science", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "System", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "Utility", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "Video", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "Addons", GINT_TO_POINTER (1));
-
-	/* ignore core apps */
-	g_hash_table_insert (ignore_cats, (gpointer) "Core", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "PackageManager", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "TerminalEmulator", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "Settings", GINT_TO_POINTER (1));
-	g_hash_table_insert (ignore_cats, (gpointer) "other", GINT_TO_POINTER (1));
-
-	/* search categories for the search term */
-	array = as_store_get_apps (plugin->priv->store);
-	for (i = 0; i < array->len; i++) {
-		item = g_ptr_array_index (array, i);
-
-		/* find installed desktop applications */
-		if (as_app_get_state (item) != AS_APP_STATE_INSTALLED)
-			continue;
-		if (as_app_get_id_kind (item) != AS_ID_KIND_DESKTOP)
-			continue;
-		if (as_app_get_source_kind (item) == AS_APP_SOURCE_KIND_DESKTOP)
-			continue;
-
-		/* find non-installed apps with appdata in any category */
-		categories = as_app_get_categories (item);
-		for (j = 0; j < categories->len; j++) {
-			tmp = g_ptr_array_index (categories, j);
-			if (g_hash_table_lookup (ignore_cats, tmp) != NULL)
-				continue;
-			ret = gs_plugin_add_popular_from_category (plugin,
-								   list,
-								   tmp,
-								   category_exclude,
-								   ignore_apps,
-								   error);
-			if (!ret)
-				goto out;
-		}
-
-	}
-out:
-	gs_profile_stop (plugin->profile, "appstream::add_popular[cat]");
-	return ret;
-}
-
-/**
- * gs_plugin_add_popular_by_source:
- */
-static gboolean
-gs_plugin_add_popular_by_source (GsPlugin *plugin,
-				 GList **list,
-				 GCancellable *cancellable,
-				 GError **error)
-{
-	AsApp *item;
-	GPtrArray *array;
-	gboolean ret = TRUE;
-	guint i;
-	_cleanup_hashtable_unref_ GHashTable *installed = NULL;	/* srcpkg : AsApp */
-
-	/* get already installed applications */
-	gs_profile_start (plugin->profile, "appstream::add_popular[source]");
-	installed = g_hash_table_new (g_str_hash, g_str_equal);
-	array = as_store_get_apps (plugin->priv->store);
-	for (i = 0; i < array->len; i++) {
-		item = g_ptr_array_index (array, i);
-		if (as_app_get_state (item) != AS_APP_STATE_INSTALLED)
-			continue;
-		if (as_app_get_id_kind (item) != AS_ID_KIND_DESKTOP)
-			continue;
-		if (as_app_get_source_pkgname (item) == NULL)
-			continue;
-		g_hash_table_insert (installed,
-				     (gpointer) as_app_get_source_pkgname (item),
-				     (gpointer) item);
-	}
-
-	/* search categories for the search term */
-	for (i = 0; i < array->len; i++) {
-		_cleanup_object_unref_ GsApp *app = NULL;
-		item = g_ptr_array_index (array, i);
-
-		/* find not installed desktop applications */
-		if (as_app_get_state (item) == AS_APP_STATE_INSTALLED)
-			continue;
-		if (as_app_get_id_kind (item) != AS_ID_KIND_DESKTOP)
-			continue;
-		if (as_app_get_source_pkgname (item) == NULL)
-			continue;
-
-		/* have we got an app installed with the same source name */
-		if (g_hash_table_lookup (installed, as_app_get_source_pkgname (item)) == NULL)
-			continue;
-
-		/* add application */
-		app = gs_app_new (as_app_get_id (item));
-		ret = gs_plugin_refine_item (plugin, app, item, error);
-		if (!ret)
-			goto out;
-
-		/* only suggest awesome apps */
-		if (gs_plugin_appstream_is_app_awesome (app)) {
-			g_debug ("suggesting %s as others installed from source %s",
-				 as_app_get_id (item),
-				 as_app_get_source_pkgname (item));
-			gs_plugin_add_app (list, app);
-		} else {
-			g_debug ("not suggesting %s as not awesome enough",
-				 as_app_get_id (item));
-		}
-	}
-out:
-	gs_profile_stop (plugin->profile, "appstream::add_popular[source]");
-	return ret;
-}
-
-/**
- * gs_plugin_add_popular:
- */
-gboolean
-gs_plugin_add_popular (GsPlugin *plugin,
-			GList **list,
-			const gchar *category,
-			const gchar *category_exclude,
-			GCancellable *cancellable,
-			GError **error)
-{
-	AsApp *item;
-	GPtrArray *array;
-	gboolean ret = TRUE;
-	guint i;
-	_cleanup_hashtable_unref_ GHashTable *ignore_apps = NULL;
-
-	/* load XML files */
-	if (g_once_init_enter (&plugin->priv->done_init)) {
-		ret = gs_plugin_startup (plugin, error);
-		g_once_init_leave (&plugin->priv->done_init, TRUE);
-		if (!ret)
-			return FALSE;
-	}
-	gs_profile_start (plugin->profile, "appstream::add_popular");
-	g_mutex_lock (&plugin->priv->store_mutex);
-
-	/* get already installed applications */
-	ignore_apps = g_hash_table_new (g_str_hash, g_str_equal);
-	array = as_store_get_apps (plugin->priv->store);
-	for (i = 0; i < array->len; i++) {
-		item = g_ptr_array_index (array, i);
-		if (as_app_get_state (item) != AS_APP_STATE_INSTALLED)
-			continue;
-		g_hash_table_insert (ignore_apps,
-				     (gpointer) as_app_get_id (item),
-				     GINT_TO_POINTER (1));
-	}
-
-	if (category == NULL) {
-		/* use category heuristic */
-		ret = gs_plugin_add_popular_by_cat (plugin,
-		                                    list,
-		                                    category_exclude,
-		                                    ignore_apps,
-		                                    cancellable,
-		                                    error);
-		if (!ret)
-			goto out;
-
-		/* use source-package heuristic */
-		ret = gs_plugin_add_popular_by_source (plugin, list, cancellable, error);
-		if (!ret)
-			goto out;
-	} else {
-		ret = gs_plugin_add_popular_from_category (plugin,
-							   list,
-							   category,
-							   NULL,
-							   ignore_apps,
-							   error);
-		if (!ret)
-			goto out;
-	}
-
-out:
-	g_mutex_unlock (&plugin->priv->store_mutex);
-	gs_profile_stop (plugin->profile, "appstream::add_popular");
-	return ret;
-}
