@@ -54,10 +54,9 @@ gs_plugin_fwupd_setup_networking (GsPlugin *plugin, GError **error)
 		return TRUE;
 
 	/* set up a session */
-	plugin->priv->session = soup_session_sync_new_with_options (SOUP_SESSION_USER_AGENT,
-								    "gnome-software",
-								    SOUP_SESSION_TIMEOUT, 5000,
-								    NULL);
+	plugin->priv->session = soup_session_new_with_options (SOUP_SESSION_USER_AGENT,
+	                                                       "gnome-software",
+	                                                       NULL);
 	if (plugin->priv->session == NULL) {
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
@@ -66,8 +65,6 @@ gs_plugin_fwupd_setup_networking (GsPlugin *plugin, GError **error)
 			     plugin->name);
 		return FALSE;
 	}
-	soup_session_add_feature_by_type (plugin->priv->session,
-					  SOUP_TYPE_PROXY_RESOLVER_DEFAULT);
 	return TRUE;
 }
 
@@ -676,7 +673,7 @@ gs_plugin_fwupd_upgrade (GsPlugin *plugin,
 /**
  * gs_plugin_app_upgrade:
  */
-gboolean
+static gboolean
 gs_plugin_app_upgrade (GsPlugin *plugin,
 		       GsApp *app,
 		       GCancellable *cancellable,
@@ -685,6 +682,10 @@ gs_plugin_app_upgrade (GsPlugin *plugin,
 	const gchar *device_id;
 	const gchar *filename;
 
+	/* only process this app if was created by this plugin */
+	if (g_strcmp0 (gs_app_get_management_plugin (app), "fwupd") != 0)
+		return TRUE;
+
 	filename = gs_app_get_source_id_default (app);
 	device_id = gs_app_get_metadata_item (app, "fwupd::DeviceID");
 	if (filename == NULL || device_id == NULL) {
@@ -703,6 +704,26 @@ gs_plugin_app_upgrade (GsPlugin *plugin,
 	return TRUE;
 }
 
+/**
+ * gs_plugin_offline_update:
+ */
+gboolean
+gs_plugin_offline_update (GsPlugin *plugin,
+                          GList *apps,
+                          GCancellable *cancellable,
+                          GError **error)
+{
+	GList *l;
+
+	for (l = apps; l != NULL; l = l->next) {
+		gboolean ret = gs_plugin_app_upgrade (plugin, GS_APP (l->data), cancellable, error);
+		if (!ret)
+			return FALSE;
+	}
+
+	return TRUE;
+}
+
 /**
  * gs_plugin_app_install:
  */
