@@ -208,11 +208,9 @@ gs_plugin_packagekit_resolve_packages_app (GsPlugin *plugin,
 				gs_app_set_name (app,
 						 GS_APP_QUALITY_LOWEST,
 						 pk_package_get_name (package));
-#if PK_CHECK_VERSION(0,9,1)
 				gs_app_set_summary (app,
 						    GS_APP_QUALITY_LOWEST,
 						    pk_package_get_summary (package));
-#endif
 			}
 		}
 	}
@@ -478,11 +476,9 @@ gs_plugin_packagekit_refine_details_app (GsPlugin *plugin,
 			gs_app_set_description (app,
 						GS_APP_QUALITY_LOWEST,
 						desc);
-#if PK_CHECK_VERSION(0,9,1)
 			gs_app_set_summary (app,
 					    GS_APP_QUALITY_LOWEST,
 					    pk_details_get_summary (details));
-#endif
 			break;
 		}
 	}
@@ -618,11 +614,9 @@ gs_plugin_packagekit_get_source_list (GsPlugin *plugin,
 	array = pk_results_get_repo_detail_array (results);
 	for (i = 0; i < array->len; i++) {
 		rd = g_ptr_array_index (array, i);
-#if PK_CHECK_VERSION(0,9,1)
 		g_hash_table_insert (plugin->priv->sources,
 				     g_strdup (pk_repo_detail_get_id (rd)),
 				     g_strdup (pk_repo_detail_get_description (rd)));
-#endif
 	}
 	return TRUE;
 }
@@ -653,21 +647,6 @@ gs_plugin_refine_requires_update_details (GsApp *app, GsPluginRefineFlags flags)
 	return (flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_UPDATE_DETAILS) > 0;
 }
 
-/**
- * gs_plugin_refine_requires_origin:
- */
-static gboolean
-gs_plugin_refine_requires_origin (GsApp *app, GsPluginRefineFlags flags)
-{
-	const gchar *tmp;
-	tmp = gs_app_get_origin (app);
-	if (tmp != NULL)
-		return FALSE;
-	if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_ORIGIN) > 0)
-		return TRUE;
-	return FALSE;
-}
-
 /**
  * gs_plugin_refine_requires_package_id:
  */
@@ -692,6 +671,8 @@ gs_plugin_refine_requires_package_id (GsApp *app, GsPluginRefineFlags flags)
 		return TRUE;
 	if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_UPDATE_DETAILS) > 0)
 		return TRUE;
+	if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_ORIGIN) > 0)
+		return TRUE;
 	return FALSE;
 }
 
@@ -736,7 +717,6 @@ gs_plugin_refine (GsPlugin *plugin,
 			continue;
 		if (gs_app_get_state (app) == AS_APP_STATE_UNKNOWN ||
 		    gs_plugin_refine_requires_package_id (app, flags) ||
-		    gs_plugin_refine_requires_origin (app, flags) ||
 		    gs_plugin_refine_requires_version (app, flags)) {
 			resolve_all = g_list_prepend (resolve_all, app);
 		}
